title = 'pyredq'
description = 'Light and fast ordered message queue for Python3 using Redis'
url = 'https://github.com/adrianchifor/pyredq'
version = '0.3.0'
author = 'Adrian Chifor'
author_email = 'me@adrianchifor.com'
license = 'Apache License 2.0'



import threading

from redis import Redis
from msgpack import packb, unpackb


class RedisQueue(object):
    def __init__(self, **redis_args):
        self.redis = Redis(**redis_args)

    def put(self, queue: str, message):
        if not queue:
            raise ValueError("'queue' argument cannot be None/empty")
        if not message:
            raise ValueError("'message' argument cannot be None/empty")

        msg_packed = packb(message)
        self.redis.rpush(f"pyredq:{queue}", msg_packed)

    def subscribe(self, queue: str, callback, background: bool = False):
        if not queue:
            raise ValueError("'queue' argument cannot be None/empty")
        if not callback:
            raise ValueError("'callback' function argument cannot be None")

        if background:
            t = threading.Thread(target=self._blocking_pop, args=(queue, callback))
            t.setDaemon(True)
            t.start()
        else:
            self._blocking_pop(queue, callback)

    def _blocking_pop(self, queue: str, callback):
        print(f"pyredq -- Subscribed to messages on '{queue}'", flush=True)
        while True:
            _, msg = self.redis.blpop(f"pyredq:{queue}")
            if msg:
                msg_unpacked = unpackb(msg)
                callback(msg_unpacked)



#!/usr/bin/env python3

from pyredq.version import title, description, url, author, author_email, license, version
from setuptools import setup, find_packages


def install_deps():
    with open('requirements.txt', 'r') as f:
        packages = f.readlines()
        new_pkgs = []
        links = []
        for resource in packages:
            if 'git+https' in resource:
                pkg = resource.split('#')[-1]
                links.append(resource.strip() + '-9876543210')
                new_pkgs.append(pkg.replace('egg=', '').rstrip())
            else:
                new_pkgs.append(resource.strip())
        return new_pkgs, links


pkgs, new_links = install_deps()

setup(
    name=title,
    description=description,
    long_description=url,
    url=url,
    author=author,
    author_email=author_email,
    license=license,
    version=version,

    classifiers=[
        'Development Status :: 4 - Beta',

        'Intended Audience :: Developers',

        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: System :: Distributed Computing',

        'License :: OSI Approved :: Apache Software License',

        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7'
    ],

    keywords='redis ordered distributed queue pubsub',
    py_modules=["pyredq"],
    python_requires=">=3.6",
    packages=find_packages(),
    include_package_data=True,
    dependency_links=new_links,
    install_requires=pkgs,
)
